==> haskell-ci-0.16.6-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ci.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-haskell-ci-z-haskell-ci-internal
version:              0.16.6
package-name:         haskell-ci
lib-name:             haskell-ci-internal
id:
    haskell-ci-0.16.6-2T071qX9IrWBk9HOZtfdUs-haskell-ci-internal

key:
    haskell-ci-0.16.6-2T071qX9IrWBk9HOZtfdUs-haskell-ci-internal

license:              GPL-3.0-or-later
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Cabal package script generator for Travis-CI
description:
    Script generator (@haskell-ci@) for
    [GitHub Actions](https://docs.github.com/en/actions) and
    [Travis-CI](https://travis-ci.org/)
    for continuous-integration testing of Haskell Cabal packages.

    Included features (not limited to):

    * Multiple GHC support
    * Dependency caching
    * cabal.project support (see [Nix-style local builds documentation](https://cabal.readthedocs.io/en/latest/nix-local-build-overview.html))
    * Runs tests and builds benchmarks
    * Generates Haddocks
    * GHCJS support
    * building with specific constraints

    === Quick Start Guide

    Add a @tested-with@ line to your @.cabal@ file (e.g. @tested-with: GHC == 8.0.2 || == 8.2.2@) and then run @haskell-ci yourpackage.cabal -o .travis.yml@ to generate the Travis-CI job script.

    See @haskell-ci --help@ for more information.

category:             Development
abi:                  7926619e24afcbf512a5bf1065309f63
exposed-modules:
    HaskellCI HaskellCI.Auxiliary HaskellCI.Bash
    HaskellCI.Bash.Template HaskellCI.Cabal HaskellCI.Cli
    HaskellCI.Compiler HaskellCI.Config HaskellCI.Config.Components
    HaskellCI.Config.ConstraintSet HaskellCI.Config.CopyFields
    HaskellCI.Config.Docspec HaskellCI.Config.Doctest
    HaskellCI.Config.Dump HaskellCI.Config.Empty HaskellCI.Config.Folds
    HaskellCI.Config.HLint HaskellCI.Config.Installed
    HaskellCI.Config.Jobs HaskellCI.Config.PackageScope
    HaskellCI.Config.Ubuntu HaskellCI.Config.Validity
    HaskellCI.Diagnostics HaskellCI.Error HaskellCI.Ghcup
    HaskellCI.GitConfig HaskellCI.GitHub HaskellCI.GitHub.Yaml
    HaskellCI.HeadHackage HaskellCI.Jobs HaskellCI.List
    HaskellCI.MonadErr HaskellCI.Newtypes HaskellCI.OptionsGrammar
    HaskellCI.OptparseGrammar HaskellCI.Package HaskellCI.ParsecUtils
    HaskellCI.Prelude HaskellCI.Sh HaskellCI.ShVersionRange
    HaskellCI.TestedWith HaskellCI.Tools HaskellCI.Travis
    HaskellCI.Travis.Yaml HaskellCI.VersionInfo HaskellCI.YamlSyntax

import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-ci-0.16.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-ci-0.16.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-ci-0.16.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ci
hs-libraries:
    HShaskell-ci-0.16.6-2T071qX9IrWBk9HOZtfdUs-haskell-ci-internal

depends:
    Cabal-syntax-3.8.1.0 HsYAML-0.2.1.5-CNpBacKavO6JhPOeUlbB77
    ShellCheck-0.11.0-9PcveALcV5cGpEwKE5EsZb
    aeson-2.1.2.1-CoFGCad0PesDH4XC5ctCv4
    attoparsec-0.14.4-5QXKAIXHnspGYO0JElIsOr base-4.17.2.1
    base-compat-0.14.0-D6ySGt5shRqHRPQXrHl9Oo
    base16-bytestring-1.0.2.0-ISe9mmeVuu6374zTlmWEXC binary-0.8.9.1
    bytestring-0.11.5.3
    cabal-install-parsers-0.6-9XdUfzEC0svLvjdaSmllMN containers-0.6.7
    cryptohash-sha256-0.11.102.1-JBWXGSDAQ7g3JohDhEeY6e deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    generic-lens-lite-0.1.1-fdAG00wdys4njg4MryBwd
    indexed-traversable-0.1.4-4tpIJXRq7N27Ef4t7nI4Bs
    indexed-traversable-instances-0.1.2-5sYZdzRQwlN5BR1dvZZ71H
    ini-0.4.2-GbbhxukYvp3mWDCX324r
    lattices-2.2.1-2S35waPnLasI9FeHPfSMeW mtl-2.2.2
    network-uri-2.6.4.2-4IxerK0JG7wGRLJekUQEdr
    optparse-applicative-0.18.1.0-CZp2uWBrZhVKrqP7dbntdc
    parsec-3.1.16.1 pretty-1.1.3.6 process-1.6.18.0
    temporary-1.3-GqTQQZxhgaKHMmG7i0IazO text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-9wNMaDmysQKAAHkxxaXhUB
    zinza-0.2-3QNNSrDrWkl35r4w9ZT1EA

haddock-interfaces:   /usr/share/doc/haskell-ci/html/haskell-ci.haddock
haddock-html:         /usr/share/doc/haskell-ci/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ci-0.16.6-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ci.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-haskell-ci-z-haskell-ci-internal
version:              0.16.6
package-name:         haskell-ci
lib-name:             haskell-ci-internal
id:
    haskell-ci-0.16.6-2ONVGo8xo1DB202hRhjo7j-haskell-ci-internal

key:
    haskell-ci-0.16.6-2ONVGo8xo1DB202hRhjo7j-haskell-ci-internal

license:              GPL-3.0-or-later
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Cabal package script generator for Travis-CI
description:
    Script generator (@haskell-ci@) for
    [GitHub Actions](https://docs.github.com/en/actions) and
    [Travis-CI](https://travis-ci.org/)
    for continuous-integration testing of Haskell Cabal packages.

    Included features (not limited to):

    * Multiple GHC support
    * Dependency caching
    * cabal.project support (see [Nix-style local builds documentation](https://cabal.readthedocs.io/en/latest/nix-local-build-overview.html))
    * Runs tests and builds benchmarks
    * Generates Haddocks
    * GHCJS support
    * building with specific constraints

    === Quick Start Guide

    Add a @tested-with@ line to your @.cabal@ file (e.g. @tested-with: GHC == 8.0.2 || == 8.2.2@) and then run @haskell-ci yourpackage.cabal -o .travis.yml@ to generate the Travis-CI job script.

    See @haskell-ci --help@ for more information.

category:             Development
abi:                  85acb008cf1cd58691218012dc687c83
exposed-modules:
    HaskellCI HaskellCI.Auxiliary HaskellCI.Bash
    HaskellCI.Bash.Template HaskellCI.Cabal HaskellCI.Cli
    HaskellCI.Compiler HaskellCI.Config HaskellCI.Config.Components
    HaskellCI.Config.ConstraintSet HaskellCI.Config.CopyFields
    HaskellCI.Config.Docspec HaskellCI.Config.Doctest
    HaskellCI.Config.Dump HaskellCI.Config.Empty HaskellCI.Config.Folds
    HaskellCI.Config.HLint HaskellCI.Config.Installed
    HaskellCI.Config.Jobs HaskellCI.Config.PackageScope
    HaskellCI.Config.Ubuntu HaskellCI.Config.Validity
    HaskellCI.Diagnostics HaskellCI.Error HaskellCI.Ghcup
    HaskellCI.GitConfig HaskellCI.GitHub HaskellCI.GitHub.Yaml
    HaskellCI.HeadHackage HaskellCI.Jobs HaskellCI.List
    HaskellCI.MonadErr HaskellCI.Newtypes HaskellCI.OptionsGrammar
    HaskellCI.OptparseGrammar HaskellCI.Package HaskellCI.ParsecUtils
    HaskellCI.Prelude HaskellCI.Sh HaskellCI.ShVersionRange
    HaskellCI.TestedWith HaskellCI.Tools HaskellCI.Travis
    HaskellCI.Travis.Yaml HaskellCI.VersionInfo HaskellCI.YamlSyntax

import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-ci-0.16.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-ci-0.16.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-ci-0.16.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ci
hs-libraries:
    HShaskell-ci-0.16.6-2ONVGo8xo1DB202hRhjo7j-haskell-ci-internal

depends:
    Cabal-syntax-3.8.1.0 HsYAML-0.2.1.5-91CHVJZVfB28FJ811VTFpE
    ShellCheck-0.11.0-5MQGf7QWTUP1TZOolOhH1C
    aeson-2.1.2.1-IUt8ms8F4mK1p5ihNOaPfT
    attoparsec-0.14.4-99Ep8AgC5YbKR8GAd3oR9D base-4.17.2.1
    base-compat-0.14.0-D6ySGt5shRqHRPQXrHl9Oo
    base16-bytestring-1.0.2.0-LZaHEQn0vqb9PYOvTA7u4b binary-0.8.9.1
    bytestring-0.11.5.3
    cabal-install-parsers-0.6-JK9cuFUVULIGHk7i675YW0 containers-0.6.7
    cryptohash-sha256-0.11.102.1-DrDFxEsKaKP7NumyjswTSY deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    generic-lens-lite-0.1.1-fdAG00wdys4njg4MryBwd
    indexed-traversable-0.1.4-JYfisWLMyBh1BEfbVJsUp6
    indexed-traversable-instances-0.1.2-8eU0xXxk8f3CrsWfMNyA8F
    ini-0.4.2-Jh7mO8iSuiQ12WLMgcL8iz
    lattices-2.2.1-LrZmcvbGqgeA7XvrueTWCN mtl-2.2.2
    network-uri-2.6.4.2-FdqTTZWnFNX96ukBHXQ0ED
    optparse-applicative-0.18.1.0-5pRc89gLzX8JqTyOujyDZt
    parsec-3.1.16.1 pretty-1.1.3.6 process-1.6.18.0
    temporary-1.3-sx8gB5yETjAWMh3lNT3tk text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-8z8yrOH3Dwd8Gc78vZRE2k
    zinza-0.2-9CBuQjr6hGkz0Tcx55zFx

haddock-interfaces:   /usr/share/doc/haskell-ci/html/haskell-ci.haddock
haddock-html:         /usr/share/doc/haskell-ci/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
